| Title: | A Wes Anderson Palette Generator |
|---|---|
| Description: | Palettes generated mostly from 'Wes Anderson' movies. |
| Authors: | Karthik Ram [aut, cre] (ORCID: <https://orcid.org/0000-0002-0233-1757>), Hadley Wickham [aut], Clark Richards [ctb], Aaron Baggett [ctb] |
| Maintainer: | Karthik Ram <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.3.7 |
| Built: | 2026-05-19 06:51:58 UTC |
| Source: | https://github.com/karthik/wesanderson |
A heatmap example
heatmapheatmap
An object of class data.frame with 144 rows and 5 columns.
These are a handful of color palettes from Wes Anderson movies.
wes_palette(name, n, type = c("discrete", "continuous"))wes_palette(name, n, type = c("discrete", "continuous"))
name |
Name of desired palette. Choices are:
|
n |
Number of colors desired. Unfortunately most palettes now only have 4 or 5 colors. But hopefully we'll add more palettes soon. All color schemes are derived from the most excellent Tumblr blog: Wes Anderson Palettes. If omitted, uses all colours. |
type |
Either "continuous" or "discrete". Use continuous if you want to automatically interpolate between colours. @importFrom graphics rgb rect par image text |
A vector of colours.
wes_palette("Royal1") wes_palette("GrandBudapest1") wes_palette("Cavalcanti1") wes_palette("Cavalcanti1", 3) # If you need more colours than normally found in a palette, you # can use a continuous palette to interpolate between existing # colours pal <- wes_palette(21, name = "Zissou1", type = "continuous") image(volcano, col = pal)wes_palette("Royal1") wes_palette("GrandBudapest1") wes_palette("Cavalcanti1") wes_palette("Cavalcanti1", 3) # If you need more colours than normally found in a palette, you # can use a continuous palette to interpolate between existing # colours pal <- wes_palette(21, name = "Zissou1", type = "continuous") image(volcano, col = pal)
Use wes_palette to construct palettes of desired length.
wes_paletteswes_palettes
An object of class list of length 24.
list of palettes from Wes Anderson movies
list of palettes from Wes Anderson movies